@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::CmdLineParsingModules;
 
-our $VERSION = 0.06; # VERSION
+our $VERSION = 0.07; # VERSION
 
 our $results = [
   [
@@ -9,75 +9,111 @@ our $results = [
     [
       {
         dataset     => "4args",
-        errors      => 1.2e-08,
+        errors      => 5.3e-08,
         participant => "Parse::CommandLine::parse_command_line",
         rate        => 34000,
-        samples     => 24,
-        time        => 29.4,
+        samples     => 20,
+        time        => 29,
+        vs_slowest  => 1,
+      },
+      {
+        dataset     => "4args",
+        errors      => 5.3e-08,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 34000,
+        samples     => 20,
+        time        => 29,
         vs_slowest  => 1,
       },
       {
         dataset     => "4args",
         errors      => 1.3e-08,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 38100,
+        rate        => 38400,
         samples     => 20,
-        time        => 26.2,
-        vs_slowest  => 1.12,
+        time        => 26.1,
+        vs_slowest  => 1.13,
       },
       {
         dataset     => "2args-simple",
-        errors      => 1.3e-08,
-        participant => "Complete::Bash::parse_cmdline",
-        rate        => 93000,
+        errors      => 1e-08,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 83700,
         samples     => 20,
-        time        => 11,
-        vs_slowest  => 2.7,
+        time        => 11.9,
+        vs_slowest  => 2.46,
       },
       {
         dataset     => "2args-simple",
-        errors      => 3.3e-09,
-        participant => "Parse::CommandLine::parse_command_line",
-        rate        => 137000,
-        samples     => 20,
-        time        => 7.29,
-        vs_slowest  => 4.03,
-      },
-      {
-        dataset     => "cmd-only",
-        errors      => 6.5e-09,
+        errors      => 2.9e-09,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 220000,
-        samples     => 21,
-        time        => 4.5,
-        vs_slowest  => 6.5,
+        rate        => 93400,
+        samples     => 26,
+        time        => 10.7,
+        vs_slowest  => 2.74,
+      },
+      {
+        dataset     => "2args-simple",
+        errors      => 2.2e-08,
+        participant => "Parse::CommandLine::parse_command_line",
+        rate        => 130000,
+        samples     => 37,
+        time        => 7.8,
+        vs_slowest  => 3.8,
       },
       {
         dataset     => "cmd-only",
-        errors      => 6.7e-10,
-        participant => "Parse::CommandLine::parse_command_line",
-        rate        => 354000,
-        samples     => 31,
-        time        => 2.82,
-        vs_slowest  => 10.4,
-      },
-      {
-        dataset     => "empty",
         errors      => 1.7e-09,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 1300000,
+        rate        => 214000,
         samples     => 20,
-        time        => 0.8,
-        vs_slowest  => 37,
+        time        => 4.67,
+        vs_slowest  => 6.28,
+      },
+      {
+        dataset     => "cmd-only",
+        errors      => 1.7e-09,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 216000,
+        samples     => 20,
+        time        => 4.62,
+        vs_slowest  => 6.35,
+      },
+      {
+        dataset     => "cmd-only",
+        errors      => 7.9e-10,
+        participant => "Parse::CommandLine::parse_command_line",
+        rate        => 358000,
+        samples     => 22,
+        time        => 2.79,
+        vs_slowest  => 10.5,
       },
       {
         dataset     => "empty",
-        errors      => 0,
-        participant => "Parse::CommandLine::parse_command_line",
-        rate        => 2949820,
+        errors      => 1e-11,
+        participant => "Text::ParseWords::shellwords",
+        rate        => 1181000,
         samples     => 20,
-        time        => 0.339004,
-        vs_slowest  => 86.6955,
+        time        => 0.8466,
+        vs_slowest  => 34.66,
+      },
+      {
+        dataset     => "empty",
+        errors      => 2.9e-11,
+        participant => "Complete::Bash::parse_cmdline",
+        rate        => 1276000,
+        samples     => 20,
+        time        => 0.7839,
+        vs_slowest  => 37.43,
+      },
+      {
+        dataset     => "empty",
+        errors      => 6.1e-10,
+        participant => "Parse::CommandLine::parse_command_line",
+        rate        => 3000000,
+        samples     => 21,
+        time        => 0.34,
+        vs_slowest  => 87,
       },
     ],
     {
@@ -200,7 +236,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2600.007,
+                                              speed                        => 2768.007,
                                               stepping                     => 4,
                                             },
                                             {
@@ -315,7 +351,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2708.726,
+                                              speed                        => 2600.007,
                                               stepping                     => 4,
                                             },
                                             {
@@ -430,7 +466,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2755.265,
+                                              speed                        => 2870.054,
                                               stepping                     => 4,
                                             },
                                             {
@@ -545,24 +581,25 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2717.421,
+                                              speed                        => 2599.953,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.198591947555542,
+      "func.elapsed_time"              => 0.325592994689941,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.034,
+                                            "__PACKAGE__"                              => 1.036,
                                             "Bencher::Scenario::CmdLineParsingModules" => undef,
-                                            "Benchmark::Dumb" => "0.10",
-                                            "Complete::Bash" => 0.31,
-                                            "Devel::Platform::Info" => 0.16,
-                                            "Parse::CommandLine" => 0.02,
-                                            "perl" => "v5.24.0",
-                                            "Sys::Info" => 0.78,
+                                            "Benchmark::Dumb"                          => "0.10",
+                                            "Complete::Bash"                           => 0.31,
+                                            "Devel::Platform::Info"                    => 0.16,
+                                            "Parse::CommandLine"                       => 0.02,
+                                            "perl"                                     => "v5.24.0",
+                                            "Sys::Info"                                => 0.78,
+                                            "Text::ParseWords"                         => "3.30",
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0, 1], "dataset", [0 .. 3]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0, 1, 2], "dataset", [0 .. 3]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "rosa",
@@ -588,13 +625,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::CmdLineParsingModules",
-      "func.scenario_module_md5sum"    => "12bc01864890d9ddf42df343999ca747",
-      "func.scenario_module_mtime"     => 1467033075,
-      "func.scenario_module_sha1sum"   => "98de2dc9dad823f84373d07a0b901f6630790db5",
-      "func.scenario_module_sha256sum" => "3425def50615dd4e2132f6358b606c217c14e891016e8231cd134d9becb24c45",
-      "func.time_end"                  => 1485317488.84062,
+      "func.scenario_module_md5sum"    => "7762abd55864f9518393c4a6d6822a7e",
+      "func.scenario_module_mtime"     => 1495581503,
+      "func.scenario_module_sha1sum"   => "f1a2e5a0f1131c55ab1b90463ca58c6e30c2bda4",
+      "func.scenario_module_sha256sum" => "d181752859155e4a7f13554551fd659bd21c291d0f5d9fad68e5e2dd987d6954",
+      "func.time_end"                  => 1495581627.22335,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1485317488.64203,
+      "func.time_start"                => 1495581626.89775,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
